@@ -82,6 +82,9 @@ def create_credential_resolver(session, cache=None, region_name=None):
             session
         ),
         'ec2_credential_refresh_window': _DEFAULT_ADVISORY_REFRESH_TIMEOUT,
+        'ec2_metadata_v1_disabled': session.get_config_variable(
+            'ec2_metadata_v1_disabled'
+        ),
     }
 
     if cache is None:
@@ -438,7 +441,6 @@ class AioAssumeRoleCredentialFetcher(
         )
 
 
-# black: # fmt: skip (ing) this line triggers internal black error
 class AioAssumeRoleWithWebIdentityCredentialFetcher(
     AioBaseAssumeRoleCredentialFetcher
 ):
@@ -451,7 +453,6 @@ class AioAssumeRoleWithWebIdentityCredentialFetcher(
         cache=None,
         expiry_window_seconds=None,
     ):
-
         self._web_identity_token_loader = web_identity_token_loader
 
         super().__init__(
